use Acme::Palindrome;
 	 	 	 	 	 	 	 	
                                  }
       ;"n\.ytterp si _$" tnirp    
             { ) slamina@ ( hcaerof
                                   
;]woc ynop god tac[wq = slamina@ ym
                                   
